@@ -33,6 +33,7 @@
 #include "main.h"
 #include "types.h"
 #include "global.h"
+#include "printer.h"
 #include "chart.h"
 #include "element.h"
 #include "load.h"
@@ -107,15 +108,7 @@ void
 on_s2p_files1_activate                 (GtkMenuItem     *menuitem,
                                         gpointer         user_data)
 {
-
-}
-
-
-void
-on_export_postscript1_activate         (GtkMenuItem     *menuitem,
-                                        gpointer         user_data)
-{
-  recalculate_all_export();
+  s2p_files1_activate();
 }
 
 
@@ -206,7 +199,7 @@ void
 on_recalc_btn_clicked                  (GtkButton       *button,
                                         gpointer         user_data)
 {
-  recalculate_all();
+  recalculate_all(DST_SCREEN);
 }
 
 
@@ -214,7 +207,7 @@ void
 on_z0_cbbox_changed                    (GtkComboBox     *combobox,
                                         gpointer         user_data)
 {
-  recalculate_all();
+  recalculate_all(DST_SCREEN);
   save_config();
 }
 
@@ -240,7 +233,7 @@ on_direction_cbbox_changed             (GtkComboBox     *combobox,
 	    break;
   }
   if (prev_rot != pref.rotation)
-    recalculate_all();
+    recalculate_all(DST_SCREEN);
 }
 
 
@@ -519,7 +512,7 @@ on_circ_treeview_cursor_changed        (GtkTreeView     *treeview,
                                         gpointer         user_data)
 {
   fetch_selected_element(treeview, &act_el);
-  recalculate_all();
+  recalculate_all(DST_SCREEN);
 }
 
 
@@ -567,7 +560,6 @@ on_ConfigWindow_realize                (GtkWidget       *widget,
                                         gpointer         user_data)
 {
   load_configwindow(widget);
-  print_load_font_list(GTK_COMBO(lookup_widget(widget, "prt_font_combo")));
 }
 
 
@@ -733,7 +725,7 @@ void
 on_import_s2p_sel_all_btn_clicked          (GtkButton       *button,
                                         gpointer         user_data)
 {
-
+  import_s2p_sel_all_btn_clicked();
 }
 
 
@@ -741,7 +733,7 @@ void
 on_import_s2p_sel_none_btn_clicked         (GtkButton       *button,
                                         gpointer         user_data)
 {
-
+  import_s2p_sel_none_btn_clicked();
 }
 
 
@@ -749,7 +741,7 @@ void
 on_import_s2p_sel_invert_btn_clicked       (GtkButton       *button,
                                         gpointer         user_data)
 {
-
+  import_s2p_sel_invert_btn_clicked();
 }
 
 
@@ -762,9 +754,25 @@ on_import_s2p_cancel_btn_clicked           (GtkButton       *button,
 
 
 void
-on_import_s2p_exec_btn_clicked             (GtkButton       *button,
+on_import_s2p_impS11_btn_clicked       (GtkButton       *button,
                                         gpointer         user_data)
 {
-  import_s2p_exec_btn_clicked();
+  import_s2p_impS11_btn_clicked();
+}
+
+
+void
+on_import_s2p_impS22_btn_clicked       (GtkButton       *button,
+                                        gpointer         user_data)
+{
+  import_s2p_impS22_btn_clicked();
+}
+
+
+void
+on_print1_activate                     (GtkMenuItem     *menuitem,
+                                        gpointer         user_data)
+{
+  print_chart(pref.last_ps_file);
 }
 
