@@ -46,14 +46,14 @@
 gdouble 	 chartw, charth, z0 = 50.0,
 		 last_lw = 0.1;
 gboolean	 logomode = TRUE,
-		 imp_mode = TRUE,
-		 printchart = FALSE;
+		 imp_mode = TRUE;
 complex		 act_imp;
 int		 load_nr,
 		 el_nr,
 		 nr_els,
 		 last_color = 0,
-		 zoom_factor = 0;
+		 zoom_factor = 0,
+		 plot_dest = DST_SCREEN;
 GnomeCanvas	 *chart_canvas = NULL;
 GnomeCanvasItem	 *chart_bg = NULL,
 		 *swr_circle = NULL;
@@ -195,22 +195,21 @@ draw_swr_circle(double swr)
     gtk_object_destroy(GTK_OBJECT(swr_circle));
 
   setlinestyle(&bg_group, 1, pref.swr_color);
-  swr_circle = k_arc(&bg_group, z0/swr - 0.001*I,
-                                z0/swr + 0.001*I, z0);
+  swr_circle = k_arc(&bg_group, pref.chart_z0/swr - 0.001*I,
+                                pref.chart_z0/swr + 0.001*I, pref.chart_z0);
 }
 
 
 void
 draw_extras(void)
 {
-  double z0 = pref.chart_z0;
-
   if (pref.show_swr)
     draw_swr_circle(pref.swr_circle);
 
   if (pref.show_g1) {
     setlinestyle(&bg_group, 1, pref.g1_color);
-    rg_arc(&bg_group, 50 - 1e5*I, 50 + 1e5*I, pref.chart_z0, FALSE);
+    rg_arc(&bg_group, pref.chart_z0 - 1e5*I, pref.chart_z0 + 1e5*I, 
+	pref.chart_z0, FALSE);
   }
 }
 
@@ -290,7 +289,7 @@ update_cursor_values(int x, int y)
   stop_logomode();
   pos2impedance(&imp, wx, wy);
   
-  k = reflection_coef(imp, z0);
+  k = reflection_coef(imp, pref.chart_z0);
   if (cabs(k) == 1.0) {
     swr = 9999.9;
   } else {
@@ -469,7 +468,7 @@ show_point(chart_pt pt)
   x = 1 + creal(k);
   y = cimag(k);
 
-  if (printchart)
+  if (plot_dest == DST_PRINT)
     print_point(x, y, pt->style);
 
   s2 = pref.point_size[pt->style]/2;
@@ -686,7 +685,7 @@ add_line_to_list(el_definition *el, complex prev_imp, double f)
         case ELC_SERIES:
           setlinestyle(&ln->group, 1, pref.arc_color[Z_ARC]);
           ln->line = rg_arc(&ln->group, imp1, imp2, pref.chart_z0, imp_mode);
-          if (printchart) {
+          if (plot_dest == DST_PRINT) {
             print_setlinestyle(pref.prt_arc_size[Z_ARC],
                                pref.prt_arc_color[Z_ARC]);
             ln->line = rg_arc(NULL, imp1, imp2, pref.chart_z0, imp_mode);
@@ -696,7 +695,7 @@ add_line_to_list(el_definition *el, complex prev_imp, double f)
           setlinestyle(&ln->group, 1, pref.arc_color[Y_ARC]);
           ln->line = rg_arc(&ln->group, reciprocal(imp2), reciprocal(imp1),
 		pref.chart_z0, !imp_mode);
-          if (printchart) {
+          if (plot_dest == DST_PRINT) {
             print_setlinestyle(pref.prt_arc_size[Y_ARC],
                                pref.prt_arc_color[Y_ARC]);
             ln->line = rg_arc(NULL, reciprocal(imp2), reciprocal(imp1),
@@ -712,7 +711,7 @@ add_line_to_list(el_definition *el, complex prev_imp, double f)
       else
         ln->line = k_arc(&ln->group, reciprocal(act_imp), 
 			reciprocal(prev_imp), el->z0);
-      if (printchart) {
+      if (plot_dest == DST_PRINT) {
         print_setlinestyle(pref.prt_arc_size[K_ARC],
                            pref.prt_arc_color[K_ARC]);
         if (imp_mode)
@@ -725,7 +724,7 @@ add_line_to_list(el_definition *el, complex prev_imp, double f)
     case ELT_ZY:
       setlinestyle(&ln->group, 1, pref.arc_color[ZY_LINE]);
       ln->line = zy_line(&ln->group, act_imp);
-      if (printchart) {
+      if (plot_dest == DST_PRINT) {
         print_setlinestyle(pref.prt_arc_size[ZY_LINE],
                            pref.prt_arc_color[ZY_LINE]);
         ln->line = zy_line(NULL, act_imp);
@@ -845,10 +844,11 @@ recalculate_elements(void)
 
 
 void
-recalculate_all(void)
+recalculate_all(int dest)
 {
   update_chart_z0();
 
+  plot_dest = dest;
   loglist_create(number_loads(), number_elements());
   recalculate_loads();
   recalculate_elements();
@@ -856,30 +856,6 @@ recalculate_all(void)
 }
 
 
-void
-recalculate_all_export(void)
-{
-  if (run_filedialog(_("Postscript filename:"), pref.last_ps_file, TRUE,
-		_("Postsript files"), "*.ps", 
-		_("All files"), "*",
-		NULL)) {
-    if (g_file_test(pref.last_ps_file, G_FILE_TEST_EXISTS)) {
-      if (ok_cancel_dialog(_("Confirmation"), 
-          _("This file already exists.\n"
-	    "Pressing Ok will overwrite it.")) == 1) return;
-    }
-    create_printer_chart();
-  } else
-    return;
-
-  printchart = TRUE;
-  recalculate_all();
-  printchart = FALSE;
-
-  close_printer_chart();
-}
-
-
 //---------------------------------------------------------------------
 //	Chart element generation
 //	arcs are in radians!
@@ -902,10 +878,8 @@ setlinestyle(GnomeCanvasGroup **grp, double lw, int color)
 void
 setfontstyle(GnomeCanvasGroup **grp, char *font, double size, int color)
 {
-  if (!grp) {
+  if (!grp)
     print_setfontstyle(font, size, color);
-    return;
-  }
 }
 
 
@@ -1146,7 +1120,7 @@ create_printer_chart(void)
   int el;
   complex cmin, cmax;
   
-  print_new_page(pref.last_ps_file);
+//  print_chart();
   for (el = 0; el < nrpldefs; el++) {
     switch (pldef[el].type) {
       case 'R':
@@ -1189,8 +1163,8 @@ create_printer_chart(void)
 
   if (pref.show_swr) {
     setlinestyle(NULL, pref.prt_swr_size, pref.prt_swr_color);
-    k_arc(NULL, z0/pref.swr_circle - 1e-5*I,
-                z0/pref.swr_circle + 1e-5*I, z0);
+    k_arc(NULL, pref.chart_z0/pref.swr_circle - 1e-5*I,
+                pref.chart_z0/pref.swr_circle + 1e-5*I, pref.chart_z0);
   }
   if (pref.show_g1) {
     setlinestyle(NULL, pref.prt_g1_size, pref.prt_g1_color);
@@ -1199,13 +1173,6 @@ create_printer_chart(void)
 }
 
 
-void
-close_printer_chart()
-{
-  print_close_page();
-}
-
-
 void
 test_routine(void)
 {
