@@ -61,8 +61,7 @@ void		create_printer_chart(void);
 void		close_printer_chart(void);
 
 void		update_chart_z0(void);
-void		recalculate_all(void);
-void		recalculate_all_export(void);
+void		recalculate_all(int dest);
 
 void		test_routine(void);
 void		change_zoom(int how);
