@@ -34,7 +34,7 @@ enum {CFM_W_CBTN,
       CFM_W_LABEL_DOUBLE,
       CFM_W_CLIST,
       CFM_W_CBOX,
-      CFM_W_COLORPICK,
+      CFM_W_COLORBUTTON,
       CFM_W_FONTBUTTON};
 
 enum {CFM_T_INT,
