@@ -29,6 +29,7 @@
 
 #include "support.h"
 #include "callbacks.h"
+#include "printer.h"
 #include "main.h"
 #include "global.h"
 #include "chart.h"
@@ -578,7 +579,7 @@ element_update(el_definition el)
   elements_changed = TRUE;
   gtk_tree_selection_select_iter(sel, &active_el_iter);
   act_el = el;
-  recalculate_all();
+  recalculate_all(DST_SCREEN);
 
   enable_circ_buttons(CIRCLIST_UPDATED);
 }
