@@ -53,6 +53,10 @@ extern	GtkWidget *el_view;
 extern	el_definition act_el;
 extern	GtkTreeIter active_el_iter;
       
+void  	load3_activate(void);
+void	save_as4_activate(void);
+void	save4_activate(void);
+
 void	initialize_elementtable(void);
 int	fetch_selected_element(GtkTreeView *treeview, el_definition *el);
 
