@@ -36,7 +36,7 @@
 #include "load_rx.h"
 #include "load.h"
 #include "chart.h"
-#include "aux.h"
+#include "misc.h"
 
 typedef struct {
   char *hdr;
@@ -59,6 +59,50 @@ int		load_mode = LOADMODE_R_JX;
 //	Loads
 //---------------------------------------------------------------------
 
+void
+load4_activate(void)
+{
+  if (number_loads() != 0) {
+    switch (list_not_empty_dialog(
+	_("The load list is not empty. Selecting Append will append\n"
+	  "the new values."))) {
+      case LSTDLG_APPEND: break;
+      case LSTDLG_CLEAR : loadlist_clear(); break;
+      case LSTDLG_CANCEL: return;
+    }
+  }
+
+  if (run_filedialog(_("Load load impedances"), pref.last_ld_file, TRUE,
+		_("linSmith loads"), "*.load", 
+		_("All files"), "*",
+		NULL)){
+    load_loads(pref.last_ld_file);
+    save_file_paths();
+  }
+}
+
+void
+save5_activate(void)
+{
+  if (strlen(pref.last_ld_file) != 0)
+    save_loads(pref.last_ld_file);   
+  else
+    save_as3_activate();
+}
+
+void
+save_as3_activate(void)
+{
+  if (run_filedialog(_("Save load impedances as"), pref.last_ld_file, FALSE, 
+		_("linSmith loads"), "*.load", 
+		_("All files"), "*",
+		NULL)) {
+    save_loads(pref.last_ld_file);
+    save_file_paths();
+  }
+}
+
+
 gint
 compare_frequencies(GtkTreeModel *model, GtkTreeIter *a, GtkTreeIter *b,
 			gpointer user_data)
