@@ -272,7 +272,8 @@ loglist_export(void)
     return;
   }
 
-  if (run_filedialog(_("Result export:"), pref.last_ps_file, "*.txt")) {
+  if (run_filedialog(_("Result export:"), pref.last_ps_file,
+		"*.txt", NULL)) {
     if (g_file_test(pref.last_ps_file, G_FILE_TEST_EXISTS)) {
       if (ok_cancel_dialog(_("Confirmation"), 
           _("This file already exists.\n"
