@@ -253,14 +253,15 @@ list_not_empty_dialog(char *msg)
   return gnome_dialog_run_and_close(GNOME_DIALOG(dlg));
 }
 
-
 gboolean
 run_filedialog1(char *title, char *fn, char *filter)
 {
-  GtkWidget *fs = gtk_file_selection_new(title);
-  GtkWidget *selbtn = GTK_FILE_SELECTION(fs)->ok_button;
+  GtkWidget *fs, *selbtn;
   int result;
 
+  fs = gtk_file_selection_new(title);
+  selbtn = GTK_FILE_SELECTION(fs)->ok_button;
+
   gtk_file_selection_set_filename(GTK_FILE_SELECTION(fs), fn);
   gtk_window_set_modal(GTK_WINDOW(fs), TRUE);
 
@@ -286,13 +287,13 @@ run_filedialog(char *title, char *fn, gboolean openfile, ...)
 
   va_start(parg, openfile);
   if (openfile) {
-  fc = gtk_file_chooser_dialog_new(title, NULL, 
+    fc = gtk_file_chooser_dialog_new(title, NULL, 
 		GTK_FILE_CHOOSER_ACTION_OPEN,
 		GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
 		GTK_STOCK_OPEN, GTK_RESPONSE_ACCEPT,
 		NULL);
   } else {
-  fc = gtk_file_chooser_dialog_new(title, NULL, 
+    fc = gtk_file_chooser_dialog_new(title, NULL, 
 		GTK_FILE_CHOOSER_ACTION_SAVE,
 		GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
 		GTK_STOCK_OPEN, GTK_RESPONSE_ACCEPT,
