@@ -21,8 +21,12 @@
 
 #include <gtk/gtk.h>
 
-void		print_new_page(char *fn);
-void		print_close_page(void);
+enum {  DST_SCREEN,
+        DST_PRINT
+};
+
+void            print_chart_start(void);
+void		print_chart(char *fn);
 void		print_do_arc(double x, double y,
 		     double arcb, double arce, double rad);
 void    	print_do_line(double x1, double y1, double x2, double y2);
@@ -34,4 +38,3 @@ void		print_load_font_list(GtkCombo *combo);
 void		print_setlinestyle(double lw, int color);
 gboolean	print_setfontstyle(char *font, double size, int color);
 
-void		print_test(void);
