@@ -4,7 +4,7 @@
 #include "support.h"
 #include "main.h"
 #include "global.h"
-#include "aux.h"
+#include "misc.h"
 #include "remote.h"
 
 int
